@@ -43,11 +43,16 @@ class log:
         self.logger.addHandler(logging_handler)
 
 
-def list_dir(dir_path, exp=None,judge_func=None):
+def list_dir(dir_path, exp=None, judge_func=None):
     if exp is None and judge_func is None:
         return os.listdir(dir_path)
     else:
-        return filter_list(os.listdir(dir_path), pattern=exp,judge_func=judge_func)
+        return filter_list(os.listdir(dir_path), pattern=exp, judge_func=judge_func)
+
+
+def mk_dir(path):
+    if not os.path.exists(path):
+        os.mkdir(path)
 
 
 def read_overwrite(path, text_process_func, encoding="utf-8"):
@@ -59,13 +64,14 @@ def read_overwrite(path, text_process_func, encoding="utf-8"):
 
 
 @timebox.timeit
-def list_all_files(dir_path):
+def list_all_files(dir_, exp=None):
     lst = []
-    for root, dir, flst in os.walk(dir_path):
-        # print(root)
-        # print(dir)
-        # print(flst)
-        lst.extend([root + "\\" + f for f in flst])
+    if not exp == None:
+        __filter = lambda x: filter_list(x, pattern=exp)
+    else:
+        __filter = lambda x: x
+    for root, sub_dir, file_list in os.walk(dir_):
+        lst.extend([root + "\\" + f for f in __filter(file_list)])
     return lst
 
 
