@@ -1,5 +1,5 @@
 import unittest
-from spongebox.iobox import list_dir
+from spongebox.iobox import list_dir,list_all_files
 
 class MyTestCase(unittest.TestCase):
     def test_something(self):
@@ -14,6 +14,10 @@ class MyTestCase(unittest.TestCase):
         print(list(list_dir(".",exp="\.py")))
         self.assertEqual(True, True)
 
+    def test_sth3(self):
+        print(list(list_all_files("C:\\Users\\LuoJi\\Documents\\Coding\\spongebox\\spongebox",exp="box")))
+        self.assertEqual(True, True)
+
 
 if __name__ == '__main__':
     unittest.main()
